@@ -10,6 +10,69 @@ import utils.objectUtils as obj
 from pyparsing import And, Suppress,Dict, Word, Literal, Group, Optional, ZeroOrMore, OneOrMore, Regex, restOfLine, alphanums,nums, printables, string, CaselessKeyword,nestedExpr,ParseException,quotedString,removeQuotes,originalTextFor,delimitedList,QuotedString
 
 
+def drop_table(table_name,schema_name=None,if_exists=True,quote_char="`"):
+    '''
+        Generate a drop table SQL statement.
+
+        ----------
+
+        Arguments
+        -------------------------
+        `table_name` {str}
+            The name of the table to drop.
+
+        [`schema_name`=None] {str}
+            The name of the schema the table belongs to.
+
+        [`if_exists`=True] {bool}
+            if False, the "IF EXISTS" test will not be added.
+
+        [`quote_char`="`"] {str}
+            The character to use to quote the schema and table name.
+
+        Return {str}
+        ----------------------
+        The drop table statement.
+
+
+        Examples
+        ----------------------
+
+        drop_table('goth_girl','smol_titty',True)
+
+        DROP TABLE IF EXISTS \`smol_titty\`.\`goth_girl\`;
+
+        ----------------------
+
+        drop_table('goth_girl','smol_titty',False,"'")
+
+        DROP TABLE 'smol_titty'.'goth_girl';
+
+        Meta
+        ----------
+        `author`: Colemen Atwood
+        `created`: 06-01-2022 10:19:29
+        `memberOf`: parse_sql
+        `version`: 1.0
+        `method_name`: drop_table
+        # @TODO []: documentation for drop_table
+    '''
+
+
+    exist_string = ""
+    schema_string = ""
+    if isinstance(quote_char,(str)):
+        quote_char = quote_char[0]
+    else:
+        quote_char = "`"
+
+    if schema_string is not None:
+        schema_string = f"`{schema_name}`."
+    if if_exists is True:
+        exist_string = " IF EXISTS"
+    return f'''DROP TABLE{exist_string} {schema_string}`{table_name}`;'''
+
+
 
 def strip_comments(value):
     '''
@@ -309,7 +372,7 @@ def parse_table_statement(value=None):
     # TODO []: remove this!!! it is for testing only!!!!!
     # value = "DROP TABLE IF EXISTS `idealech_Equari_Management_Database`.`blackholes`;"
 
-    
+
 
     _tick,_double_quote,_single_quote,_period = [Suppress(x) for x in list('`"\'.')]
     _quote = (_tick|_double_quote|_single_quote)
