@@ -649,7 +649,12 @@ def reverse_title_case(value):
         return result
 
 
+def strip_empty_lines(value):
+    lines = value.split("\n")
+    new_lines = [x for x in lines if len(x) > 0]
+    return '\n'.join(new_lines)
 
 
 # ----------========== ALIASES ==========----------
 left_pad = leftPad
+
